@@ -1,17 +1,18 @@
+from .config_store import Config
 from contextlib import contextmanager
 import sys, os
 
 
 @contextmanager
-def cd(path=os.path.expanduser(os.getenv('IOT49', '~'))):
+def cd(path=Config.iot49_dir()):
     cwd = os.getcwd()
-    os.chdir(os.path.expanduser(path))
+    os.chdir(os.path.expandvars(os.path.expanduser(path)))
     try:
         yield
     finally:
         os.chdir(cwd)
-        
-        
+
+
 @contextmanager
 def redirect_stdout_stderr(out, err):
     # temporarily redirect stdout, stderr
